@@ -13,6 +13,7 @@
 # limitations under the License.
 
 """Execute Transactions Spec tests."""
+from __future__ import annotations
 
 import os
 import sys
@@ -24,7 +25,7 @@ from test import IntegrationTest, client_knobs, unittest
 from test.pymongo_mocks import DummyMonitor
 from test.utils import (
     CMAPListener,
-    TestCreator,
+    SpecTestCreator,
     camel_to_snake,
     client_context,
     get_pool,
@@ -123,19 +124,19 @@ class TestCMAP(IntegrationTest):
     def check_out(self, op):
         """Run the 'checkOut' operation."""
         label = op["label"]
-        with self.pool.get_socket() as sock_info:
+        with self.pool.checkout() as conn:
             # Call 'pin_cursor' so we can hold the socket.
-            sock_info.pin_cursor()
+            conn.pin_cursor()
             if label:
-                self.labels[label] = sock_info
+                self.labels[label] = conn
             else:
-                self.addCleanup(sock_info.close_socket, None)
+                self.addCleanup(conn.close_conn, None)
 
     def check_in(self, op):
         """Run the 'checkIn' operation."""
         label = op["connection"]
-        sock_info = self.labels[label]
-        self.pool.return_socket(sock_info)
+        conn = self.labels[label]
+        self.pool.checkin(conn)
 
     def ready(self, op):
         """Run the 'ready' operation."""
@@ -270,7 +271,7 @@ class TestCMAP(IntegrationTest):
             for t in self.targets.values():
                 t.join(5)
             for conn in self.labels.values():
-                conn.close_socket(None)
+                conn.close_conn(None)
 
         self.addCleanup(cleanup)
 
@@ -444,7 +445,7 @@ class TestCMAP(IntegrationTest):
         self.assertEqual(1, listener.event_count(PoolClearedEvent))
         self.assertEqual(PoolState.READY, pool.state)
         # Checking out a connection should succeed
-        with pool.get_socket():
+        with pool.checkout():
             pass
 
 
@@ -455,7 +456,7 @@ def create_test(scenario_def, test, name):
     return run_scenario
 
 
-class CMAPTestCreator(TestCreator):
+class CMAPSpecTestCreator(SpecTestCreator):
     def tests(self, scenario_def):
         """Extract the tests from a spec file.
 
@@ -465,7 +466,7 @@ class CMAPTestCreator(TestCreator):
         return [scenario_def]
 
 
-test_creator = CMAPTestCreator(create_test, TestCMAP, TestCMAP.TEST_PATH)
+test_creator = CMAPSpecTestCreator(create_test, TestCMAP, TestCMAP.TEST_PATH)
 test_creator.create_tests()
 
 
