@@ -13,6 +13,7 @@
 # limitations under the License.
 
 """Test the topology module."""
+from __future__ import annotations
 
 import os
 import sys
@@ -34,6 +35,7 @@ from test.utils import (
     single_client,
     wait_until,
 )
+from unittest.mock import patch
 
 from bson import Timestamp, json_util
 from pymongo import common, monitoring
@@ -94,7 +96,7 @@ def got_app_error(topology, app_error):
     when = app_error["when"]
     max_wire_version = app_error["maxWireVersion"]
     # XXX: We could get better test coverage by mocking the errors on the
-    # Pool/SocketInfo.
+    # Pool/Connection.
     try:
         if error_type == "command":
             _check_command_response(app_error["response"], max_wire_version)
@@ -274,14 +276,14 @@ class TestIgnoreStaleErrors(IntegrationTest):
         client.admin.command("ping")
         pool = get_pool(client)
         starting_generation = pool.gen.get_overall()
-        wait_until(lambda: len(pool.sockets) == N_THREADS, "created sockets")
+        wait_until(lambda: len(pool.conns) == N_THREADS, "created conns")
 
         def mock_command(*args, **kwargs):
             # Synchronize all threads to ensure they use the same generation.
             barrier.wait()
-            raise AutoReconnect("mock SocketInfo.command error")
+            raise AutoReconnect("mock Connection.command error")
 
-        for sock in pool.sockets:
+        for sock in pool.conns:
             sock.command = mock_command
 
         def insert_command(i):
@@ -341,6 +343,59 @@ class TestPoolManagement(IntegrationTest):
             listener.wait_for_event(monitoring.PoolReadyEvent, 1)
 
 
+class TestServerMonitoringMode(IntegrationTest):
+    @client_context.require_no_serverless
+    @client_context.require_no_load_balancer
+    def setUp(self):
+        super().setUp()
+
+    def test_rtt_connection_is_enabled_stream(self):
+        client = rs_or_single_client(serverMonitoringMode="stream")
+        self.addCleanup(client.close)
+        client.admin.command("ping")
+
+        def predicate():
+            for _, server in client._topology._servers.items():
+                monitor = server._monitor
+                if not monitor._stream:
+                    return False
+                if client_context.version >= (4, 4):
+                    if monitor._rtt_monitor._executor._thread is None:
+                        return False
+                else:
+                    if monitor._rtt_monitor._executor._thread is not None:
+                        return False
+            return True
+
+        wait_until(predicate, "find all RTT monitors")
+
+    def test_rtt_connection_is_disabled_poll(self):
+        client = rs_or_single_client(serverMonitoringMode="poll")
+        self.addCleanup(client.close)
+        self.assert_rtt_connection_is_disabled(client)
+
+    def test_rtt_connection_is_disabled_auto(self):
+        envs = [
+            {"AWS_EXECUTION_ENV": "AWS_Lambda_python3.9"},
+            {"FUNCTIONS_WORKER_RUNTIME": "python"},
+            {"K_SERVICE": "gcpservicename"},
+            {"FUNCTION_NAME": "gcpfunctionname"},
+            {"VERCEL": "1"},
+        ]
+        for env in envs:
+            with patch.dict("os.environ", env):
+                client = rs_or_single_client(serverMonitoringMode="auto")
+                self.addCleanup(client.close)
+                self.assert_rtt_connection_is_disabled(client)
+
+    def assert_rtt_connection_is_disabled(self, client):
+        client.admin.command("ping")
+        for _, server in client._topology._servers.items():
+            monitor = server._monitor
+            self.assertFalse(monitor._stream)
+            self.assertIsNone(monitor._rtt_monitor._executor._thread)
+
+
 # Generate unified tests.
 globals().update(generate_test_classes(os.path.join(SDAM_PATH, "unified"), module=__name__))
 
