@@ -13,6 +13,7 @@
 # limitations under the License.
 
 """Test the topology module."""
+from __future__ import annotations
 
 import sys
 
@@ -52,7 +53,7 @@ def create_mock_topology(
     topology_settings = TopologySettings(
         partitioned_seeds,
         replica_set_name=replica_set_name,
-        pool_class=MockPool,
+        pool_class=MockPool,  # type: ignore[arg-type]
         monitor_class=monitor_class,
         direct_connection=direct_connection,
     )
@@ -451,7 +452,7 @@ class TestMultiServerTopology(TopologyTest):
         # Discovering a replica set without the setName supplied by the user
         # is not yet supported by MongoClient, but Topology can do it.
         topology_settings = SetNameDiscoverySettings(
-            seeds=[address], pool_class=MockPool, monitor_class=DummyMonitor
+            seeds=[address], pool_class=MockPool, monitor_class=DummyMonitor  # type: ignore[arg-type]
         )
 
         t = Topology(topology_settings)
@@ -479,7 +480,7 @@ class TestMultiServerTopology(TopologyTest):
         # Discovering a replica set without the setName supplied by the user
         # is not yet supported by MongoClient, but Topology can do it.
         topology_settings = SetNameDiscoverySettings(
-            seeds=[address], pool_class=MockPool, monitor_class=DummyMonitor
+            seeds=[address], pool_class=MockPool, monitor_class=DummyMonitor  # type: ignore[arg-type]
         )
 
         t = Topology(topology_settings)
@@ -647,13 +648,13 @@ class TestMultiServerTopology(TopologyTest):
         )
         self.assertEqual(
             repr(t.description),
-            "<TopologyDescription id: {}, "
+            f"<TopologyDescription id: {t._topology_id}, "
             "topology_type: ReplicaSetWithPrimary, servers: ["
             "<ServerDescription ('a', 27017) server_type: RSPrimary, rtt: 0>, "
             "<ServerDescription ('b', 27017) server_type: Unknown,"
             " rtt: None>, "
             "<ServerDescription ('c', 27017) server_type: Unknown,"
-            " rtt: None>]>".format(t._topology_id),
+            " rtt: None>]>",
         )
 
     def test_unexpected_load_balancer(self):
