@@ -13,6 +13,7 @@
 # limitations under the License.
 
 """Utilities for testing pymongo"""
+from __future__ import annotations
 
 import contextlib
 import copy
@@ -279,12 +280,12 @@ class HeartbeatEventListener(BaseListener, monitoring.ServerHeartbeatListener):
         self.add_event(event)
 
 
-class MockSocketInfo:
+class MockConnection:
     def __init__(self):
         self.cancel_context = _CancellationContext()
         self.more_to_come = False
 
-    def close_socket(self, reason):
+    def close_conn(self, reason):
         pass
 
     def __enter__(self):
@@ -300,14 +301,15 @@ class MockPool:
         self._lock = _create_lock()
         self.opts = options
         self.operation_count = 0
+        self.conns = []
 
     def stale_generation(self, gen, service_id):
         return self.gen.stale(gen, service_id)
 
-    def get_socket(self, handler=None):
-        return MockSocketInfo()
+    def checkout(self, handler=None):
+        return MockConnection()
 
-    def return_socket(self, *args, **kwargs):
+    def checkin(self, *args, **kwargs):
         pass
 
     def _reset(self, service_id=None):
@@ -391,7 +393,7 @@ class FunctionCallRecorder:
         return len(self._call_list)
 
 
-class TestCreator:
+class SpecTestCreator:
     """Class to create test cases from specifications."""
 
     def __init__(self, create_test, test_class, test_path):
@@ -541,7 +543,7 @@ class TestCreator:
 def _connection_string(h):
     if h.startswith(("mongodb://", "mongodb+srv://")):
         return h
-    return f"mongodb://{str(h)}"
+    return f"mongodb://{h!s}"
 
 
 def _mongo_client(host, port, authenticate=True, directConnection=None, **kwargs):
@@ -720,7 +722,8 @@ def server_started_with_auth(client):
     try:
         command_line = get_command_line(client)
     except OperationFailure as e:
-        msg = e.details.get("errmsg", "")  # type: ignore
+        assert e.details is not None
+        msg = e.details.get("errmsg", "")
         if e.code == 13 or "unauthorized" in msg or "login" in msg:
             # Unauthorized.
             return True
